YearNames

Enum YearNames 

pub enum YearNames<'data> {
    FixedEras(VarZeroVec<'data, str>),
    VariableEras(VarZeroCow<'data, Tuple2VarULE<VarZeroSlice<PotentialUtf8>, VarZeroSlice<str>>>),
    Cyclic(VarZeroVec<'data, str>),
}
Names used for representing the year.

๐Ÿ“ This item has a stack size of 32 bytes on the stable toolchain at release date.

๐Ÿšง This code is considered unstable; it may change at any time, in breaking or non-breaking ways, including in SemVer minor releases. While the serde representation of data structs is guaranteed to be stable, their Rust representation might not be. Use with caution.

Variants



FixedEras(VarZeroVec<'data, str>)

This calendar has a small, fixed set of eras.

See era_index for how this is keyed.



VariableEras(VarZeroCow<'data, Tuple2VarULE<VarZeroSlice<PotentialUtf8>, VarZeroSlice<str>>>)

This calendar has a variable set of eras with numeric years, this stores the era names mapped from era code to the name.



Cyclic(VarZeroVec<'data, str>)

This calendar is cyclic (Chinese, Dangi), so it uses cyclic year names without any eras