RangeStructure

Enum RangeStructure 

#[repr(u8)]
pub enum RangeStructure { Absent = 0, Symmetric = 1, FullRange = 2, }
The structure of a range pattern for a specific field.

Variants



Absent = 0

No pattern is present for this field. (0 patterns)



Symmetric = 1

Symmetric pattern: [sub] [shared_glue] [sub]. (1 pattern)



FullRange = 2

Full Range pattern: the entire range pattern is stored. (1 pattern)

Implementations

Source

impl RangeStructure

pub const fn from_bits(bits: u8) -> Self

Creates a RangeStructure from a 2-bit value.

pub const fn num_patterns(self) -> usize

Returns the number of patterns stored for this structure.