pub struct GreatestDifferenceHeader(pub u8);Expand description
A bitset encoding which fields are present in the GreatestDifference pattern list
and their range structure.
Date and time fields reuse the same bits (0-7) because they are stored in separate range pattern collections (date vs time).
Each of the 4 fields uses 2 bits to encode its RangeStructure, going from smallest field to largest:
- Bits 0-1: Field 0 (Day/Minute)
- Bits 2-3: Field 1 (Month/Hour)
- Bits 4-5: Field 2 (Year/Flexible Day Period)
- Bits 6-7: Field 3 (Era/Day Period)
Tuple Fields
0: u8Implementations
Sourceimpl GreatestDifferenceHeader
impl GreatestDifferenceHeader
Sourcepub const fn get_state(self, field_idx: u8) -> RangeStructure
pub const fn get_state(self, field_idx: u8) -> RangeStructure
Get the range structure for a specific field index (0-3).
Sourcepub fn set_state(&mut self, field_idx: u8, state: RangeStructure)
pub fn set_state(&mut self, field_idx: u8, state: RangeStructure)
Set the range structure for a specific field index (0-3). Used during datagen.
Sourcepub const fn is_date_field_present(
self,
field: DateGreatestDifferenceField,
) -> bool
pub const fn is_date_field_present( self, field: DateGreatestDifferenceField, ) -> bool
Returns whether the given date field is present in this header.
Sourcepub const fn is_time_field_present(
self,
field: TimeGreatestDifferenceField,
) -> bool
pub const fn is_time_field_present( self, field: TimeGreatestDifferenceField, ) -> bool
Returns whether the given time field is present in this header.
Sourcepub const fn get_pattern_index(self, field_idx: u8) -> usize
pub const fn get_pattern_index(self, field_idx: u8) -> usize
Calculate the starting index in the flat patterns list for a given field index (0-3).
Sourcepub const fn total_patterns(self) -> usize
pub const fn total_patterns(self) -> usize
Calculate the total number of patterns stored under this header.